import os
from trino.dbapi import connect as connect_to_trino  # type: ignore


def connect(
    host: str = "host.docker.internal",
    port: int = int(os.environ.get("TRINO_HOST_PORT", 8080)),
    user: str = os.environ.get("TRINO_USER", "trino"),
    catalog: str = "iceberg",
    schema: str = "raw",
):
    return connect_to_trino(
        host=host,
        port=port,
        user=user,
        catalog=catalog,
        schema=schema,
    )



import os
from pathlib import Path
from nbdev.processors import NBProcessor  # type: ignore
from nbdev.export import scrub_magics  # type: ignore
from sidetrek.nbdev.directives import DbtMaker, ExportDBTProc
from fastcore.foundation import L  # type: ignore


def nb_export_dbt(nb_path, procs=None, debug=False, dbt_maker=DbtMaker, name=None):
    """
    Create dbt files from notebook. Defaults to removing all magics from the cell.

    Example usage:
    nb_export_dbt('path/to/notebook')
    """
    nb_dirname = os.path.dirname(nb_path)
    exp = ExportDBTProc()
    nb = NBProcessor(nb_path, [exp] + L(procs) + L([scrub_magics]), debug=debug)
    nb.process()
    for filepath, cell in exp.file_content.items():
        dest_filepath = str(Path(nb_dirname) / filepath)
        dm = dbt_maker(dest=dest_filepath, nb_path=nb_path)
        dm.make(cell)



import io
import os
import re
from IPython.core.magic import register_cell_magic
from IPython.core.magic_arguments import argument, magic_arguments, parse_argstring

@magic_arguments()
@argument(
    "-p",
    "--prepend-content",
    help=("Prepend content to the file (Optional: defaults to '# AUTOGENERATED! DO NOT EDIT!\n\n')"),
)
@argument("filepath", type=str, help=("Filepath to write the file to (Required)"))
@register_cell_magic
def writefile_dbt(line, cell):
    "Write a file to disk and skip execution (overwrites the existing file if the file already exists)"
    args = parse_argstring(writefile_dbt, line)
    filepath = args.filepath

    if re.match(r'^(\'.*\')|(".*")$', filepath):
        # If the filepath is wrapped in quotes, remove them
        full_path = os.path.expanduser(filepath[1:-1])
    else:
        full_path = os.path.expanduser(filepath)

    if os.path.exists(full_path):
        print(f"Overwriting {full_path}")
    else:
        print(f"Writing {full_path}")

    prepend_content = args.prepend_content or f"-- AUTOGENERATED! DO NOT EDIT! File to edit: {filepath}.\n\n"
    mode = "w"

    with io.open(full_path, mode, encoding="utf-8") as f:
        # Remove the #| directive from the cell
        cell_lines = cell.splitlines(True)
        stripped_cell = ''.join([line for line in cell_lines if "#|" not in line])
        content = f"{prepend_content}{stripped_cell}"
        f.write(content)

    return



import os
from pathlib import Path
from collections import defaultdict
from fastcore.foundation import L  # type: ignore
from fastcore.basics import ifnone  # type: ignore
from nbdev.config import write_cells  # type: ignore


class DbtMaker:
    "Helper class to create a dbt file from notebook source cells"

    def __init__(self, dest, nb_path):
        self.dest_dbt_filepath = Path(dest)
        self.dest_dirname = Path(os.path.dirname(dest))
        self.dest_dirname.mkdir(parents=True, exist_ok=True)
        self.dest_nb = os.path.relpath(Path(nb_path), self.dest_dirname)
        self.hdr = f"-- %% {self.dest_nb}"

    def make(self, cell):
        with self.dest_dbt_filepath.open("w", encoding="utf-8") as f:
            f.write(f"-- AUTOGENERATED! DO NOT EDIT! File to edit: {self.dest_nb}.")
            cells = L([cell])
            write_cells(cells, self.hdr, f)
            f.write("\n")


class ExportDBTProc:
    """
    A processor which exports dbt code to a dbt file. Each cell with this directive will be exported as a separate file.

    Args:
    - The file to write the dbt code to.

    Example usage:
    #|export_dbt models/my_model.sql
    """

    def begin(self):
        self.file_content = defaultdict(L)

    # exp_to_filepath is the args passed to the export_dbt directive
    def _export_dbt_(self, cell, exp_to_filepath=None):
        if exp_to_filepath is None:
            raise ValueError(
                "Please provide a filepath to export the dbt code to (i.e. #|export_dbt path/to/dbt_file.sql)."
            )
        self.file_content[exp_to_filepath] = cell
